@@ -1,5 +1,4 @@
 import os
-import warnings
 from fractions import Fraction
 from unittest import SkipTest
 
@@ -89,40 +88,17 @@ class TestCodecContext(TestCase):
     def test_decoder_gop_size(self):
         ctx = av.codec.Codec("h264", "r").create()
 
-        with warnings.catch_warnings(record=True) as captured:
-            self.assertIsInstance(ctx.gop_size, int)
-            self.assertEqual(
-                captured[0].message.args[0],
-                "Using VideoCodecContext.gop_size for decoders is deprecated.",
-            )
+        with self.assertRaises(RuntimeError):
+            ctx.gop_size
 
-    def test_frame_index(self):
-        container = av.open(fate_suite("h264/interlaced_crop.mp4"))
-        stream = container.streams[0]
-        for frame in container.decode(stream):
-            with warnings.catch_warnings(record=True) as captured:
-                self.assertIsInstance(frame.index, int)
-                self.assertEqual(
-                    captured[0].message.args[0],
-                    "Using `frame.index` is deprecated.",
-                )
-
-    def test_decoder_timebase(self):
+    def test_decoder_timebase(self) -> None:
         ctx = av.codec.Codec("h264", "r").create()
 
-        with warnings.catch_warnings(record=True) as captured:
-            self.assertIsNone(ctx.time_base)
-            self.assertEqual(
-                captured[0].message.args[0],
-                "Using CodecContext.time_base for decoders is deprecated.",
-            )
+        with self.assertRaises(RuntimeError):
+            ctx.time_base
 
-        with warnings.catch_warnings(record=True) as captured:
+        with self.assertRaises(RuntimeError):
             ctx.time_base = Fraction(1, 25)
-            self.assertEqual(
-                captured[0].message.args[0],
-                "Using CodecContext.time_base for decoders is deprecated.",
-            )
 
     def test_encoder_extradata(self):
         ctx = av.codec.Codec("h264", "w").create()
@@ -410,7 +386,6 @@ class TestEncoding(TestCase):
 
         sample_fmt = ctx.codec.audio_formats[-1].name
         sample_rate = 48000
-        channels = 2
 
         ctx.time_base = Fraction(1) / sample_rate
         ctx.sample_rate = sample_rate
@@ -429,122 +404,19 @@ class TestEncoding(TestCase):
         samples = 0
         packet_sizes = []
 
-        pts_expected = [
-            0,
-            1098,
-            2212,
-            3327,
-            4441,
-            5556,
-            6670,
-            7785,
-            8900,
-            10014,
-            11129,
-            12243,
-            13358,
-            14472,
-            15587,
-            16701,
-            17816,
-            18931,
-            20045,
-            21160,
-            22274,
-            23389,
-            24503,
-            25618,
-            26732,
-            27847,
-            28962,
-            30076,
-            31191,
-            32305,
-            33420,
-            34534,
-            35649,
-            36763,
-            37878,
-            38993,
-            40107,
-            41222,
-            42336,
-            43451,
-            44565,
-            45680,
-            46795,
-            47909,
-            49024,
-            50138,
-            51253,
-            52367,
-            53482,
-            54596,
-            55711,
-            56826,
-            57940,
-            59055,
-            60169,
-            61284,
-            62398,
-            63513,
-            64627,
-            65742,
-            66857,
-            67971,
-            69086,
-            70200,
-            71315,
-            72429,
-            73544,
-            74658,
-            75773,
-            76888,
-            78002,
-            79117,
-            80231,
-            81346,
-            82460,
-            83575,
-            84689,
-            85804,
-            86919,
-            88033,
-            89148,
-            90262,
-            91377,
-            92491,
-            93606,
-            94720,
-            95835,
-            96950,
-            98064,
-            99179,
-            100293,
-            101408,
-        ]
-        if codec_name == "aac":
-            pts_expected_encoded = list((-1024 + n * 1024 for n in range(101)))
-        elif codec_name == "mp2":
-            pts_expected_encoded = list((-481 + n * 1152 for n in range(89)))
-        else:
-            pts_expected_encoded = pts_expected.copy()
         with open(path, "wb") as f:
             for frame in iter_frames(container, audio_stream):
                 resampled_frames = resampler.resample(frame)
                 for resampled_frame in resampled_frames:
-                    self.assertEqual(resampled_frame.pts, pts_expected.pop(0))
                     self.assertEqual(resampled_frame.time_base, Fraction(1, 48000))
                     samples += resampled_frame.samples
 
                     for packet in ctx.encode(resampled_frame):
-                        self.assertEqual(packet.pts, pts_expected_encoded.pop(0))
                         self.assertEqual(packet.time_base, Fraction(1, 48000))
                         packet_sizes.append(packet.size)
                         f.write(packet)
 
             for packet in ctx.encode(None):
-                self.assertEqual(packet.pts, pts_expected_encoded.pop(0))
                 self.assertEqual(packet.time_base, Fraction(1, 48000))
                 packet_sizes.append(packet.size)
                 f.write(packet)
@@ -557,10 +429,7 @@ class TestEncoding(TestCase):
 
         result_samples = 0
 
-        # should have more asserts but not sure what to check
-        # libav and ffmpeg give different results
-        # so can really use checksums
         for frame in iter_raw_frames(path, packet_sizes, ctx):
             result_samples += frame.samples
             self.assertEqual(frame.sample_rate, sample_rate)
-            self.assertEqual(len(frame.layout.channels), channels)
+            self.assertEqual(frame.layout.nb_channels, 2)
