@@ -1,6 +1,7 @@
 import io
 import math
 from fractions import Fraction
+from typing import cast
 from unittest import SkipTest
 
 import numpy as np
@@ -10,21 +11,23 @@ from av import AudioFrame, VideoFrame
 from av.audio.stream import AudioStream
 from av.video.stream import VideoStream
 
-from .common import Image, TestCase, fate_suite
+from .common import TestCase, fate_suite, has_pillow
 
 WIDTH = 320
 HEIGHT = 240
 DURATION = 48
 
 
-def write_rgb_rotate(output):
-    if not Image:
-        raise SkipTest()
+def write_rgb_rotate(output: av.container.OutputContainer) -> None:
+    if not has_pillow:
+        raise SkipTest("Don't have Pillow")
+
+    import PIL.Image as Image
 
     output.metadata["title"] = "container"
     output.metadata["key"] = "value"
 
-    stream = output.add_stream("mpeg4", 24)
+    stream = cast(VideoStream, output.add_stream("mpeg4", 24))
     stream.width = WIDTH
     stream.height = HEIGHT
     stream.pix_fmt = "yuv420p"
@@ -118,7 +121,6 @@ def assert_rgb_rotate(self, input_, is_dash=False):
     self.assertEqual(stream.format.name, "yuv420p")
     self.assertEqual(stream.format.width, WIDTH)
     self.assertEqual(stream.format.height, HEIGHT)
-    self.assertEqual(stream.ticks_per_frame, 1)
 
 
 class TestBasicVideoEncoding(TestCase):
@@ -136,7 +138,6 @@ class TestBasicVideoEncoding(TestCase):
             self.assertEqual(stream.format.width, 640)
             self.assertEqual(stream.height, 480)
             self.assertEqual(stream.pix_fmt, "yuv420p")
-            self.assertEqual(stream.ticks_per_frame, 1)
             self.assertEqual(stream.width, 640)
 
     def test_encoding(self):
@@ -190,7 +191,6 @@ class TestBasicAudioEncoding(TestCase):
             self.assertEqual(stream.bit_rate, 128000)
             self.assertEqual(stream.format.name, "s16")
             self.assertEqual(stream.sample_rate, 48000)
-            self.assertEqual(stream.ticks_per_frame, 1)
 
     def test_transcode(self):
         path = self.sandboxed("audio_transcode.mov")
@@ -201,7 +201,6 @@ class TestBasicAudioEncoding(TestCase):
 
             sample_rate = 48000
             channel_layout = "stereo"
-            channels = 2
             sample_fmt = "s16"
 
             stream = output.add_stream("mp2", sample_rate)
@@ -212,7 +211,6 @@ class TestBasicAudioEncoding(TestCase):
             ctx.sample_rate = sample_rate
             ctx.format = sample_fmt
             ctx.layout = channel_layout
-            ctx.channels = channels
 
             with av.open(
                 fate_suite("audio-reference/chorusnoise_2ch_44kHz_s16.wav")
@@ -235,7 +233,6 @@ class TestBasicAudioEncoding(TestCase):
             self.assertIsInstance(stream, AudioStream)
 
             # codec context properties
-            self.assertEqual(stream.channels, channels)
             self.assertEqual(stream.format.name, "s16p")
             self.assertEqual(stream.sample_rate, sample_rate)
 
@@ -251,7 +248,7 @@ class TestEncodeStreamSemantics(TestCase):
 
             astream = output.add_stream("mp2", 48000)
             self.assertIn(astream, output.streams.audio)
-            astream.channels = 2
+            astream.layout = "stereo"
             astream.format = "s16"
 
             self.assertEqual(vstream.index, 0)
