@@ -27,7 +27,7 @@ def generate_audio_frame(
     frame.sample_rate = sample_rate
     frame.pts = frame_num * frame_size
 
-    for i in range(len(frame.layout.channels)):
+    for i in range(frame.layout.nb_channels):
         data = np.zeros(frame_size, dtype=format_dtypes[input_format])
         for j in range(frame_size):
             data[j] = np.sin(2 * np.pi * (frame_num + j) * (i + 1) / float(frame_size))
@@ -128,14 +128,9 @@ class TestFilters(TestCase):
             if e.errno != errno.EAGAIN:
                 raise
 
-    @staticmethod
-    def link_nodes(*nodes):
-        for c, n in zip(nodes, nodes[1:]):
-            c.link_to(n)
-
     def test_audio_buffer_resample(self):
         graph = Graph()
-        self.link_nodes(
+        graph.link_nodes(
             graph.add_abuffer(
                 format="fltp",
                 sample_rate=48000,
@@ -146,8 +141,7 @@ class TestFilters(TestCase):
                 "aformat", "sample_fmts=s16:sample_rates=44100:channel_layouts=stereo"
             ),
             graph.add("abuffersink"),
-        )
-        graph.configure()
+        ).configure()
 
         graph.push(
             generate_audio_frame(
@@ -159,9 +153,34 @@ class TestFilters(TestCase):
         self.assertEqual(out_frame.layout.name, "stereo")
         self.assertEqual(out_frame.sample_rate, 44100)
 
+    def test_audio_buffer_frame_size(self):
+        graph = Graph()
+        graph.link_nodes(
+            graph.add_abuffer(
+                format="fltp",
+                sample_rate=48000,
+                layout="stereo",
+                time_base=Fraction(1, 48000),
+            ),
+            graph.add("abuffersink"),
+        ).configure()
+        graph.set_audio_frame_size(256)
+        graph.push(
+            generate_audio_frame(
+                0,
+                input_format="fltp",
+                layout="stereo",
+                sample_rate=48000,
+                frame_size=1024,
+            )
+        )
+        out_frame = graph.pull()
+        self.assertEqual(out_frame.sample_rate, 48000)
+        self.assertEqual(out_frame.samples, 256)
+
     def test_audio_buffer_volume_filter(self):
         graph = Graph()
-        self.link_nodes(
+        graph.link_nodes(
             graph.add_abuffer(
                 format="fltp",
                 sample_rate=48000,
@@ -170,8 +189,7 @@ class TestFilters(TestCase):
             ),
             graph.add("volume", volume="0.5"),
             graph.add("abuffersink"),
-        )
-        graph.configure()
+        ).configure()
 
         input_frame = generate_audio_frame(
             0, input_format="fltp", layout="stereo", sample_rate=48000
